# streamlit-custom-component

Streamlit component that allows you to do create tags

## Installation instructions

```sh
pip install streamlit-chip-tags
```

## Usage instructions

```python
import streamlit as st

from chip_tag_component import chips_tags

value = chips_tags()

```